import os
import csv
import re
from colorama import init, Fore
from datetime import datetime

init()

def read_csv(csv_file):
    translations = {}
    with open(csv_file, mode='r', encoding='utf-8') as file:
        csv_reader = csv.reader(file)
        next(csv_reader)  
        for row in csv_reader:
            if len(row) >= 3:
                translations[row[1]] = row[2]
    return translations


def scan_and_replace(dir, translations):
    total_files = 0
    modified_files = 0
    modified_files_list = []

    for root, _, files in os.walk(dir):
        for file in files:
            if file.endswith(('.php', '.json', '.css', '.js')):
                file_path = os.path.join(root, file)
                print(f"İşleniyor: {file_path}") 
                with open(file_path, 'r', encoding='utf-8') as f:
                    file_content = f.read()

                original_content = file_content
                changed = False

                for english, turkish in translations.items():
                    pattern = re.escape(english)
                    replacement = turkish
                    file_content = re.sub(f'"{pattern}"', f'"{replacement}"', file_content)

                if file_content != original_content:
                    with open(file_path, 'w', encoding='utf-8') as f:
                        f.write(file_content)
                    print(Fore.GREEN + f"Değişiklik Yapıldı: {file_path}" + Fore.RESET)  
                    modified_files += 1
                    modified_files_list.append(file_path)
                
                total_files += 1

    return total_files, modified_files, modified_files_list

# Raporu yazdır
def print_report(total_files, modified_files, modified_files_list):
    progress = (modified_files / total_files) * 100 if total_files > 0 else 0
    print(f"Toplam Dosya: {total_files}")
    print(f"Değiştirilen Dosya: {modified_files}")
    print(f"İşlem Yüzdesi: {progress:.2f}%")

    if modified_files_list:
        print(Fore.GREEN + "Değiştirilen Dosyalar:" + Fore.RESET)
        for file in modified_files_list:
            print(Fore.GREEN + file + Fore.RESET)

    
    now = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    print(Fore.GREEN + f"{modified_files} dosya güncellendi. Tarih: {now}" + Fore.RESET)

def main():
    csv_file = 'C:/Users/EKA/ekasc/eka.csv'  
    translations = read_csv(csv_file)  
    dir = 'C:/Users/EKA/ekasc'  

    print("Tarama Başladı...")
    total_files, modified_files, modified_files_list = scan_and_replace(dir, translations)  
    print("Tarama Bitti...")

    
    print_report(total_files, modified_files, modified_files_list)

if __name__ == "__main__":
    main()
